==> openGion_dev_5.9.16.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF70S.sql <==
/****************************************************************************/
/* GF70 ( JSPﾁｪｯｸ結果ﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF70 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (   1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      varchar           ( 256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     varchar           (  60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     varchar           ( 256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     varchar           (  14 )                                       /*  60 最終更新日   */
 , TAGNAME      varchar           (  30 )                                       /*  80 ﾀｸﾞ名称      */
 , MSGCD        varchar           (  20 )                                       /*  90 ﾒｯｾｰｼﾞID     */
 , MSGTXT       varchar           ( 500 )                                       /* 100 内容         */
 , TEXT_DATA    text                                                            /* 110 ﾃｷｽﾄ         */
 , FGOMIT       varchar           (   1 )       DEFAULT 0   NOT NULL            /* 120 除外ﾌﾗｸﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF70S.sql <==
/****************************************************************************/
/* GF70 ( JSPﾁｪｯｸ結果ﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF70 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (   1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      varchar           ( 256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     varchar           (  60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     varchar           ( 256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     varchar           (  14 )                                       /*  60 最終更新日   */
 , TAGNAME      varchar           (  30 )                                       /*  80 ﾀｸﾞ名称      */
 , MSGCD        varchar           (  20 )                                       /*  90 ﾒｯｾｰｼﾞID     */
 , MSGTXT       varchar           ( 500 )                                       /* 100 内容         */
 , TEXT_DATA    text                                                            /* 110 ﾃｷｽﾄ         */
 , FGOMIT       varchar           (   1 )       DEFAULT '0' NOT NULL            /* 120 除外ﾌﾗｸﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);
